pub enum VerifySignature<T>{
Disabled,
Signed {
signature: T::Signature,
account: T::AccountId,
},
}Expand description
Extension that, if enabled, validates a signature type against the payload constructed from the
call and the rest of the transaction extension pipeline. This extension provides the
functionality that traditionally signed transactions had with the implicit signature checking
implemented in Checkable. It is meant to be placed ahead of
any other extensions that do authorization work in the [TransactionExtension] pipeline.
The variants are ordered so that the Disabled (passthrough) state encodes
as the SCALE byte 0x00, which is compatible with current signers and wallets.
Variants
Disabled
The extension is disabled and will be passthrough.
Signed
The extension will verify the signature and, if successful, authorize a traditionally signed transaction.
Implementations
Sourceimpl<T> VerifySignature<T>
impl<T> VerifySignature<T>
Sourcepub fn new_with_signature(
signature: T::Signature,
account: T::AccountId,
) -> Self
pub fn new_with_signature( signature: T::Signature, account: T::AccountId, ) -> Self
Create a new extension instance that will validate the provided signature.
Sourcepub fn new_disabled() -> Self
pub fn new_disabled() -> Self
Create a new passthrough extension instance.